Automatic Colour Conversion Graph
=================================

Conversion
----------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    convert
    describe_conversion_path
